@@ -1,6 +1,6 @@
 package Net::DNS::Packet;
 #
-# $Id: Packet.pm,v 2.102 2004/04/01 06:57:46 ctriv Exp $
+# $Id: Packet.pm 208 2005-03-02 14:59:43Z olaf $
 #
 use strict;
 use vars qw(@ISA @EXPORT_OK $VERSION $AUTOLOAD);
@@ -14,7 +14,7 @@ use Net::DNS;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-$VERSION = (qw$Revision: 2.102 $)[1];
+$VERSION = (qw$LastChangedRevision: 244 $)[1];
 
 =head1 NAME
 
@@ -86,7 +86,7 @@ sub new {
 
 		$self{"header"}->print if $debug;
 
-		my $offset = &Net::DNS::HFIXEDSZ;
+		my $offset = Net::DNS::HFIXEDSZ();
 
 		#--------------------------------------------------------------
 		# Parse the question/zone section.
@@ -260,25 +260,51 @@ sub data {
 	# section of the packet. TODO: Packet is dropped silently if is tried to
 	# have it appended to one of the other section
 
+	# Collect the data first, and count the number of records along
+	# the way. ( see rt.cpan.org: Ticket #8608 )
+	my $qdcount = 0;
+	my $ancount = 0;
+	my $nscount = 0;
+	my $arcount = 0;
+	# Note that the only pieces we;ll fill in later have predefined
+        # length.
+
+	my $headerlength=length $self->{"header"}->data;
+
 	my $data = $self->{"header"}->data;
 
 	foreach my $question (@{$self->{"question"}}) {
 		$data .= $question->data($self, length $data);
+		$qdcount++;
 	}
 
 	foreach my $rr (@{$self->{"answer"}}) {
 		$data .= $rr->data($self, length $data);
+		$ancount++;
 	}
 
 	foreach my $rr (@{$self->{"authority"}}) {
 		$data .= $rr->data($self, length $data);
+		$nscount++;
 	}
 
 	foreach my $rr (@{$self->{"additional"}}) {
 		$data .= $rr->data($self, length $data);
+		$arcount++;
 	}
 
-	return $data;
+	# Fix up the header so the counts are correct.  This overwrites
+	# the user's settings, but the user should know what they aredoing.
+	$self->{"header"}->qdcount( $qdcount );
+	$self->{"header"}->ancount( $ancount );
+	$self->{"header"}->nscount( $nscount );
+	$self->{"header"}->arcount( $arcount );
+	
+	# Replace the orginal header with corrected counts.
+
+	return $self->{"header"}->data . substr ($data,$headerlength);
+
+
 }
 
 =head2 header
@@ -330,7 +356,14 @@ must not preexist.
 
 =cut
 
-sub answer { return @{$_[0]->{'answer'}}; }
+sub answer { 
+    if (exists($_[0]->{'answer'})) {
+	return @{$_[0]->{'answer'}};
+    } else {
+	return ();
+    } 
+}
+  
 
 sub pre          { &answer }
 sub prerequisite { &answer }
@@ -347,7 +380,13 @@ specifies the RRs or RRsets to be added or delted.
 
 =cut
 
-sub authority { return @{$_[0]->{'authority'}}; }
+sub authority { 
+    if (exists($_[0]->{'authority'})) {
+	return @{$_[0]->{'authority'}};
+    } else {
+	return ();
+    } 
+}
 
 sub update    { &authority }
 
@@ -360,7 +399,13 @@ section of the packet.
 
 =cut
 
-sub additional { return @{$_[0]->{'additional'}}; }
+sub additional { 
+    if (exists($_[0]->{'additional'})) {
+	return @{$_[0]->{'additional'}};
+    } else {
+	return ();
+    } 
+}
 
 
 =head2 print
@@ -485,6 +530,7 @@ sub answersize {
 
 Adds RRs to the specified section of the packet.
 
+
 =cut
 
 sub push {
@@ -572,6 +618,7 @@ sub safe_push {
     my $rr = $packet->pop("pre");
     my $rr = $packet->pop("update");
     my $rr = $packet->pop("additional");
+    my $rr = $packet->pop("question");
 
 Removes RRs from the specified section of the packet.
 
@@ -606,7 +653,13 @@ sub pop {
 		if ($adcount) {
 			$rr = pop @{$self->{"additional"}};
 			$self->{"header"}->adcount($adcount - 1);
-		}
+		    }
+	} elsif ($section eq "question") {
+	        my $qdcount = $self->{"header"}->qdcount;
+		if ($qdcount) {
+		    	$rr = pop @{$self->{"question"}};
+			$self->{"header"}->qdcount($qdcount - 1);
+		    }
 	} else {
 		Carp::cluck(qq(invalid section "$section"\n));
 	}
@@ -688,7 +741,7 @@ sub dn_expand_PP {
 	my $name = "";
 	my $len;
 	my $packetlen = length $$packet;
-	my $int16sz = &Net::DNS::INT16SZ;
+	my $int16sz = Net::DNS::INT16SZ();
 
 	# Debugging
 	#warn "USING PURE PERL dn_expand()\n";
@@ -877,10 +930,10 @@ sub parse_question {
 	return (undef, undef) unless defined $qname;
 
 	return (undef, undef)
-		if length($$data) < ($offset + 2 * &Net::DNS::INT16SZ);
+		if length($$data) < ($offset + 2 * Net::DNS::INT16SZ());
 
 	my ($qtype, $qclass) = unpack("\@$offset n2", $$data);
-	$offset += 2 * &Net::DNS::INT16SZ;
+	$offset += 2 * Net::DNS::INT16SZ();
 
 	$qtype  = Net::DNS::typesbyval($qtype);
 	$qclass = Net::DNS::classesbyval($qclass);
@@ -910,7 +963,7 @@ sub parse_rr {
 	return (undef, undef) unless defined $name;
 
 	return (undef, undef)
-		if length($$data) < ($offset + &Net::DNS::RRFIXEDSZ);
+		if length($$data) < ($offset + Net::DNS::RRFIXEDSZ());
 
 	my ($type, $class, $ttl, $rdlength) = unpack("\@$offset n2 N n", $$data);
 
@@ -923,7 +976,7 @@ sub parse_rr {
 	} 
 	# else just keep at its numerical value
 
-	$offset += &Net::DNS::RRFIXEDSZ;
+	$offset += Net::DNS::RRFIXEDSZ();
 
 	return (undef, undef)
 		if length($$data) < ($offset + $rdlength);
@@ -948,12 +1001,14 @@ sub parse_rr {
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
+
+Portions Copyright (c) 2002-2005 Olaf Kolkman
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
 
-DNSSEC/EDNS0 functionality courtesy of Olaf M. Kolkman, RIPE NCC.  
+
 
 =head1 SEE ALSO
 
