@@ -1,14 +1,12 @@
 package Net::DNS::RR::DNAME;
 #
-# $Id: DNAME.pm,v 2.101 2004/01/04 04:31:10 ctriv Exp $
+# $Id: DNAME.pm 219 2005-03-03 14:18:10Z olaf $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$LastChangedRevision: 219 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -75,7 +73,7 @@ Returns the DNAME target.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
