@@ -1,22 +1,20 @@
 package Net::DNS::RR::MG;
 #
-# $Id: MG.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+# $Id: MG.pm 219 2005-03-03 14:18:10Z olaf $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.5 $)[1];
+$VERSION = (qw$LastChangedRevision: 219 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($mgmname) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"mgmname"} = $mgmname;
+		($self->{"mgmname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
+	
 	return bless $self, $class;
 }
 
@@ -34,9 +32,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"mgmname"}
-	       ? "$self->{mgmname}."
-	       : "; no data";
+	return exists $self->{"mgmname"} ? "$self->{mgmname}." : '';
 }
 
 sub rr_rdata {
@@ -88,7 +84,7 @@ Returns the RR's mailbox field.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
