@@ -1,14 +1,12 @@
 package Net::DNS::RR::NSAP;
 #
-# $Id: NSAP.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: NSAP.pm 219 2005-03-03 14:18:10Z olaf $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS;
-
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$LastChangedRevision: 219 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -52,8 +50,7 @@ sub new {
 			$self->{"id"}   = sprintf("%02x" x 6, @id);
 			$self->{"sel"}  = sprintf("%02x" x 1, $sel);
 
-		}
-		else {
+		} else {
 			# What to do for unsupported versions?
 		}
 	}
@@ -111,13 +108,11 @@ sub rdatastr {
 	if (exists $self->{"afi"}) {
 		if ($self->{"afi"} eq "47") {
 			$rdatastr = join('', $self->idp, $self->dsp);
-		}
-		else {
+		} else {
 			$rdatastr = "; AFI $self->{'afi'} not supported";
 		}
-	}
-	else {
-		$rdatastr = "; no data";
+	} else {
+		$rdatastr = '';
 	}
 
 	return $rdatastr;
@@ -262,7 +257,7 @@ Returns the RR's NSAP selector.
 
 Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.. 
