@@ -1,11 +1,10 @@
 package Net::DNS::RR::TSIG;
 #
-# $Id: TSIG.pm,v 2.101 2004/01/04 04:31:11 ctriv Exp $
+# $Id: TSIG.pm 219 2005-03-03 14:18:10Z olaf $
 #
 use strict;
 use vars qw(@ISA $VERSION);
 
-use Net::DNS::Packet;
 use Digest::HMAC_MD5;
 use MIME::Base64;
 
@@ -13,7 +12,7 @@ use constant DEFAULT_ALGORITHM => "HMAC-MD5.SIG-ALG.REG.INT";
 use constant DEFAULT_FUDGE     => 300;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.101 $)[1];
+$VERSION = (qw$LastChangedRevision: 219 $)[1];
 
 # a signing function for the HMAC-MD5 algorithm. This can be overridden using
 # the sign_func element
@@ -37,16 +36,16 @@ sub new {
 
 		my ($time_high, $time_low) = unpack("\@$offset nN", $$data);
 		$self->{"time_signed"} = $time_low;	# bug
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT32SZ;
+		$offset += Net::DNS::INT16SZ() + Net::DNS::INT32SZ();
 
 		@{$self}{qw(fudge mac_size)} = unpack("\@$offset nn", $$data);
-		$offset += &Net::DNS::INT16SZ + &Net::DNS::INT16SZ;
+		$offset += Net::DNS::INT16SZ() + Net::DNS::INT16SZ();
 
 		$self->{"mac"} = substr($$data, $offset, $self->{'mac_size'});
 		$offset += $self->{'mac_size'};
 
 		@{$self}{qw(original_id error other_len)} = unpack("\@$offset nnn", $$data);
-		$offset += &Net::DNS::INT16SZ * 3;
+		$offset += Net::DNS::INT16SZ() * 3;
 
 		my $odata = substr($$data, $offset, $self->{'other_len'});
 		my ($odata_high, $odata_low) = unpack("nN", $odata);
@@ -329,7 +328,7 @@ appropriate sign_func.
 
 Copyright (c) 2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2003 Chris Reinhardt.
+Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
